==> open-xchange-core_7.8.2.orig.tar.bz2: open-xchange-core-7.8.2/com.openexchange.serverconfig/src/com/openexchange/serverconfig/ServerConfigService.java <==
/*
 *
 *    OPEN-XCHANGE legal information
 *
 *    All intellectual property rights in the Software are protected by
 *    international copyright laws.
 *
 *
 *    In some countries OX, OX Open-Xchange, open xchange and OXtender
 *    as well as the corresponding Logos OX Open-Xchange and OX are registered
 *    trademarks of the OX Software GmbH group of companies.
 *    The use of the Logos is not covered by the GNU General Public License.
 *    Instead, you are allowed to use these Logos according to the terms and
 *    conditions of the Creative Commons License, Version 2.5, Attribution,
 *    Non-commercial, ShareAlike, and the interpretation of the term
 *    Non-commercial applicable to the aforementioned license is published
 *    on the web site http://www.open-xchange.com/EN/legal/index.html.
 *
 *    Please make sure that third-party modules and libraries are used
 *    according to their respective licenses.
 *
 *    Any modifications to this package must retain all copyright notices
 *    of the original copyright holder(s) for the original code used.
 *
 *    After any such modifications, the original and derivative code shall remain
 *    under the copyright of the copyright holder(s) and/or original author(s)per
 *    the Attribution and Assignment Agreement that can be located at
 *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
 *    given Attribution for the derivative code and a license granting use.
 *
 *     Copyright (C) 2016-2020 OX Software GmbH
 *     Mail: info@open-xchange.com
 *
 *
 *     This program is free software; you can redistribute it and/or modify it
 *     under the terms of the GNU General Public License, Version 2 as published
 *     by the Free Software Foundation.
 *
 *     This program is distributed in the hope that it will be useful, but
 *     WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 *     or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
 *     for more details.
 *
 *     You should have received a copy of the GNU General Public License along
 *     with this program; if not, write to the Free Software Foundation, Inc., 59
 *     Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */

package com.openexchange.serverconfig;

import com.openexchange.exception.OXException;
import com.openexchange.osgi.annotation.SingletonService;
import com.openexchange.session.Session;

/**
 * {@link ServerConfigService}
 *
 * @author <a href="mailto:marc.arens@open-xchange.com">Marc Arens</a>
 * @since v7.8.0
 */
@SingletonService
public interface ServerConfigService {

    /**
     * Gets the computed server config
     *
     * @param hostname The hostname to use when building the {@link ServerConfig}
     * @param userID The userID when building the {@link ServerConfig}
     * @param contextID The contextID when building the {@link ServerConfig}
     * @return the computed server config
     * @throws OXException if computing the server config fails
     */
    ServerConfig getServerConfig(String hostname, int userID, int contextID) throws OXException;

    /**
     * Gets the computed server config
     *
     * @param hostname The hostname to use when building the {@link ServerConfig}
     * @param session The session to use when building the {@link ServerConfig}
     * @return the computed server config
     * @throws OXException if computing the server config fails
     */
    ServerConfig getServerConfig(String hostname, Session session) throws OXException;

    /**
     * Gets the {@link ServerConfigServicesLookup} that is used when computing the server config.
     *
     * @return The look-up
     */
    ServerConfigServicesLookup getServerConfigServicesLookup();
}

==> open-xchange-core_7.8.3.orig.tar.bz2: open-xchange-core-7.8.3/com.openexchange.serverconfig/src/com/openexchange/serverconfig/ServerConfigService.java <==
/*
 *
 *    OPEN-XCHANGE legal information
 *
 *    All intellectual property rights in the Software are protected by
 *    international copyright laws.
 *
 *
 *    In some countries OX, OX Open-Xchange, open xchange and OXtender
 *    as well as the corresponding Logos OX Open-Xchange and OX are registered
 *    trademarks of the OX Software GmbH group of companies.
 *    The use of the Logos is not covered by the GNU General Public License.
 *    Instead, you are allowed to use these Logos according to the terms and
 *    conditions of the Creative Commons License, Version 2.5, Attribution,
 *    Non-commercial, ShareAlike, and the interpretation of the term
 *    Non-commercial applicable to the aforementioned license is published
 *    on the web site http://www.open-xchange.com/EN/legal/index.html.
 *
 *    Please make sure that third-party modules and libraries are used
 *    according to their respective licenses.
 *
 *    Any modifications to this package must retain all copyright notices
 *    of the original copyright holder(s) for the original code used.
 *
 *    After any such modifications, the original and derivative code shall remain
 *    under the copyright of the copyright holder(s) and/or original author(s)per
 *    the Attribution and Assignment Agreement that can be located at
 *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
 *    given Attribution for the derivative code and a license granting use.
 *
 *     Copyright (C) 2016-2020 OX Software GmbH
 *     Mail: info@open-xchange.com
 *
 *
 *     This program is free software; you can redistribute it and/or modify it
 *     under the terms of the GNU General Public License, Version 2 as published
 *     by the Free Software Foundation.
 *
 *     This program is distributed in the hope that it will be useful, but
 *     WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 *     or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
 *     for more details.
 *
 *     You should have received a copy of the GNU General Public License along
 *     with this program; if not, write to the Free Software Foundation, Inc., 59
 *     Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */

package com.openexchange.serverconfig;

import java.util.List;
import java.util.Map;
import com.openexchange.exception.OXException;
import com.openexchange.osgi.annotation.SingletonService;
import com.openexchange.session.Session;

/**
 * {@link ServerConfigService}
 *
 * @author <a href="mailto:marc.arens@open-xchange.com">Marc Arens</a>
 * @since v7.8.0
 */
@SingletonService
public interface ServerConfigService {

    /**
     * Gets the computed server config
     *
     * @param hostname The hostname to use when building the {@link ServerConfig}
     * @param userID The userID when building the {@link ServerConfig}
     * @param contextID The contextID when building the {@link ServerConfig}
     * @return the computed server config
     * @throws OXException if computing the server config fails
     */
    ServerConfig getServerConfig(String hostname, int userID, int contextID) throws OXException;

    /**
     * Gets the computed server config
     *
     * @param hostname The hostname to use when building the {@link ServerConfig}
     * @param session The session to use when building the {@link ServerConfig}
     * @return the computed server config
     * @throws OXException if computing the server config fails
     */
    ServerConfig getServerConfig(String hostname, Session session) throws OXException;

    /**
     * Gets the {@link ServerConfigServicesLookup} that is used when computing the server config.
     *
     * @return The look-up
     */
    ServerConfigServicesLookup getServerConfigServicesLookup();

    /**
     * Gets all custom properties for a given host from as-config.yml.
     *
     * @param hostName, the name of the host, to get the properties for
     * @param userID, can be -1 if no id is available at present
     * @param contextID, can be -1 if no id is available at present
     * @return the whole map with all custom properties for a host
     * @throws OXException
     */
    List<Map<String, Object>> getCustomHostConfigurations(String hostName, int userID, int contextID) throws OXException;
}
